
(function( $ ){
	"use strict";

	$.fn.slider = function(opt) 
	{
        var opt = (opt || {});
        var self = this;
        var widget = $(this);
		widget.append('<div class="slider"></div>');
		var slider = widget.children('.slider');
        $(slider).css({'margin-left': '-10px'});
		slider.append('<div class="range"></div>');
		slider.append('<div class="handle handle-left"></div>');
		slider.append('<div class="handle handle-right"></div>');
		var range = slider.children('.range');
		var left = slider.children('.handle-left');
        if("left" in opt)
            left.append(opt.left);
		var right = slider.children('.handle-right');
        if("right" in opt)
            right.append(opt.right);
		var handlers = {left: left.draggable({pos:"left"}), right: right.draggable()};


        $.each(handlers, function(index, el) {
            el.on("slider:handlerMove", function(){
                var event = jQuery.Event( "handlerMove" );
                if(opt != "" && ("min" in opt && "max" in opt))
                    event.values = self.GetValues();
                widget.trigger(event);
                recalculateRange();
            });
            el.on("slider:handlerDoneMoving", function(){
                var event = jQuery.Event( "handlerDoneMoving" );
                if(opt != "" && ("min" in opt && "max" in opt))
                    event.values = self.GetValues();
                widget.trigger(event);
                recalculateRange();
            })

        });
        $(window).resize(function(event) {
            recalculateWidget();
        });
        var lastWidth = $(window).width();
        var recalculateWidget = function()
        {
            $.each(handlers, function(index, el) {
                el.offset({left: $(window).width()/lastWidth*el.position().left});
            });
            recalculateRange();
            lastWidth = $(window).width();
        }
        var recalculateRange = function()
        {
            var el = $(range);
            el.css({
                position: 'absolute',
                height: widget.outerHeight(),
                left: handlers.left.position().left + handlers.left.outerWidth()/2 + "px",
                right: $(window).width() - handlers.right.position().left - handlers.right.outerWidth()/2 + "px"
            });
        }
        recalculateRange();

        this.SetMin = function(minimum)
        {
            opt = $.extend({min: minimum}, opt);
            return self;
        }
        this.SetMax = function(maximum)
        {
            opt = $.extend({max: maximum}, opt);
            return self;
        }
        this.SetMinMax = function(minmax)
        {
            if(!"min" in minmax || !"max" in minmax)
                throw "Minimun and maximum values must be defined right way f.e.:{min: value, max:value}";
            opt = $.extend({min: minimum, max: maximum}, opt); //vim ze se da sloucit cely minmax s opt ale nechci aby si tam mohl uzivatel ukladat neco jinyho nez potrebuju
            return self;
        }
		this.GetPercentages = function()
		{
			return { left:handlers.left.GetPercentage(), right:handlers.right.GetPercentage() };
		}
        this.GetValues = function()
        {
            if(opt == "" || !"min" in opt || !"max" in opt)
                throw "Minimun and maximum values must be defined to get values";
            return { left:opt.min+(opt.max-opt.min)*handlers.left.GetPercentage()/100, right:opt.min+(opt.max-opt.min)*handlers.right.GetPercentage()/100}
        }

		return this;
	}; 

    $.fn.draggable = function(opt) {
        opt = $.extend({cursor:"move",pos:""}, opt);
        var element = this.css('cursor', opt.cursor).on("mousedown", function(e) {
            var $drag = $(this).addClass('draggable');
            var drg_w = $drag.outerWidth(),
                pos_x = $drag.offset().left + drg_w - e.pageX,
                bor_w = $($drag[0].parentElement).outerWidth(),
                bor_x_min = 0,
                bor_x_max = 0;

            if(opt.pos=="left")
            {
                bor_x_min = $($drag[0].parentElement).position().left-drg_w/2;
                bor_x_max = $drag.next().position().left;
            }
            else
            {
                bor_x_min = $drag.prev().position().left + drg_w;
                bor_x_max = $($drag[0].parentElement).position().left + bor_w + drg_w/2;
            }
            $drag.parents().on("mousemove", function(e) {
            	$('.draggable').offset(function(i, pos){
					var drg_x = e.pageX + pos_x - drg_w,
						x = drg_x > bor_x_min ? drg_x : bor_x_min;
					if(x>bor_x_min) x = (drg_x + drg_w) < bor_x_max ? drg_x : bor_x_max - drg_w;
					if(x != pos_x)
                        $(this).trigger('slider:handlerMove');
                    return {left:x};
				}).on('mouseup', function() {
					$(this).removeClass('draggable');
				});
            });
            e.preventDefault();
        }).on("mouseup", function() {
            $(this).trigger('slider:handlerDoneMoving');
            if(opt.handle === "") {
                $(this).removeClass('draggable');
            } else {
                $(this).removeClass('active-handle').parent().removeClass('draggable');
            }
        });
        element.GetPercentage = function()
        {
        	return Math.round(($(this).position().left-$($(this)[0].parentElement).position().left)/$($(this)[0].parentElement).outerWidth() * 100)+1;
        }
        return element;
    }
})
( jQuery );

